/* Sample program that shows how to use the S-LZW with Mini-Cache Functions.  Its designed to crash
* if there is an error so that you can debug it.
* 
* Copyright (C) 2005-2006 Princeton University, Christopher M. Sadler (csadler@princeton.edu)
*
*    This program is free software; you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation; either version 2 of the License, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License along
*    with this program; if not, write to the Free Software Foundation, Inc.,
*    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "slzw.h"

#include <string.h>

int main(void) {
	unsigned int i, j, count = 0, compressed_size;
	
	// Generates 500 bytes of a small, repeating sequence.
	for (i=0; i<50; i++) {
		for (j=0; j<10;j++) {
			write_buffer[count++] = 'A' + j;
		}
	}
	
	// Use a 32 entry mini-cache.
	compressed_size = slzw_compress(500, 32);
	
	// Lets wipe out the original data so that when we decompress, we know that the data was
	// really generated by the decompressor.
	memset(write_buffer, 0x00, 500);
	
	// The result is in lzw_output_file_buffer, which is the input to the decompressor.
	if (slzw_decompress(compressed_size) != 500) {
		for (;;);
	}
	
	count = 0;
	for (i=0; i<50; i++) {
		for (j=0; j<10;j++) {
			if (write_buffer[count++] != 'A' + j) {
				for (;;);
			}
		}
	}
	
	// Success!
	for (;;);
	
	return 0;
}

