/* Sample program that shows how to use the S-LZW with Mini-Cache Functions.  
   Its designed to crash if there is an error so that you can debug it.
*/

#include <stdio.h>
#include "slzw.h"
#include <string.h>

#ifdef arm7jmf
#include "ADuC7026.h"

void initUART()
{ GP1CON = 0x00000011;  // configure SPI, setup tx & rx pins on P1.0 and P1.1
  GP4DAT = 0xff180000;  // P4.[2-4] en sortie, P4.[3,4] = 1 & P4.2 = 0
  GP2DAT = 0xff100000;  // P2.0-7 en sortie, initialises a 0;
  GP0DAT = 0xffff0000;  // P0.0-3 et P0.4-7 controlent les deux attenuateurs

  COMCON0 = 0x080;   // Setting DLAB
  COMDIV0 = 0x88;    // Setting DIV0 and DIV1 to DL 88=9600, 44=19200
  COMDIV1 = 0x000;   // *** NE PAS LANCER PAR RUN MAIS RESET DE LA CARTE ***
  COMCON0 = 0x007;   // Clearing DLAB
}
#endif

int main(void) {
 unsigned short i, j, count = 0, compressed_size;
#ifdef arm7jmf
        initUART();
#endif

for (i=0; i<500; i++) 
#ifdef arm7jmf
   write_buffer[count++]=uart0_getc();
#else
   write_buffer[count++]=getc(stdin);
#endif

 count=0;for (i=0; i<500; i++) printf("%c",write_buffer[count++]);

 printf("start compress\n");
 // Use a 32 entry mini-cache.
 // input = write_buffer, output = lzw_output_file_buffer
 compressed_size = slzw_compress(500, 32);
 printf("stop compress %d\n",compressed_size);

 // Lets wipe out the original data so that when we decompress, we 
 // know that the data was really generated by the decompressor.
 memset(write_buffer, 0x00, 500);
	
 printf("start decompress\n");
 // input = lzw_output_file_buffer, output = write_buffer 
 printf("stop decompress %d\n",slzw_decompress(compressed_size));
	
 count = 0;
 for (i=0; i<500; i++) 
#ifdef arm7jmf
   uart0_putc(write_buffer[count++]);
#else
   putc(write_buffer[count++],stdout);
#endif	

 printf("\nSuccess!\n");
 for (;;);
 return 0;
}
